# Security Policy

## Supported Versions

The project is still young, so absolutely all released ones are supported in terms of security.

## Reporting a Vulnerability

If you find a vulnerability, please report it to the author of the project (contact information can be found in the profile).

## Bug bounty program

The project is not commercial, so we do not provide any rewards for found vulnerabilities.
